/*
  NeoMatrix v1

  Contains usage examples for the NeoMatrix library.
  
  Board : METE HOCA Akana R1
  Dock  : RGB Matrix Dock Rev.1
  Core  : earlephilhower / arduino-pico (https://github.com/earlephilhower/arduino-pico)
  Required Libraries : U8G2 (https://github.com/olikraus/u8g2)
                       Adafruit NeoPixel (https://github.com/adafruit/Adafruit_NeoPixel)
                       Adafruit NeoMatrix (https://github.com/adafruit/Adafruit_NeoMatrix)
                       Adafruit GFX (https://github.com/adafruit/Adafruit-GFX-Library)
  Settings: Select METE HOCA Akana R1 as the board.

  Source: METE HOCA
  
  METE HOCA, 19 May 2024
  IG : https://www.instagram.com/metehoca/
  YT : https://www.youtube.com/MeteHoca
  WEB: https://www.metehoca.com/
*/

#include "AkanaLogo.h"

#include <Adafruit_GFX.h>
#include <Adafruit_NeoMatrix.h>
#include <Adafruit_NeoPixel.h>

int bright = 32;

#define LED_BLACK    0

#define LED_RED_LOW     (7 <<  11)
#define LED_RED_MEDIUM    (15 << 11)
#define LED_RED_HIGH    (31 << 11)

#define LED_GREEN_LOW     (15 << 5)  
#define LED_GREEN_MEDIUM  (31 << 5)  
#define LED_GREEN_HIGH    (63 << 5)  

#define LED_BLUE_LOW    7
#define LED_BLUE_MEDIUM   15
#define LED_BLUE_HIGH     31

#define LED_ORANGE_LOW    (LED_RED_LOW     + LED_GREEN_LOW)
#define LED_ORANGE_MEDIUM (LED_RED_MEDIUM  + LED_GREEN_MEDIUM)
#define LED_ORANGE_HIGH   (LED_RED_HIGH    + LED_GREEN_HIGH)

#define LED_PURPLE_LOW    (LED_RED_LOW     + LED_BLUE_LOW)
#define LED_PURPLE_MEDIUM (LED_RED_MEDIUM  + LED_BLUE_MEDIUM)
#define LED_PURPLE_HIGH   (LED_RED_HIGH    + LED_BLUE_HIGH)

#define LED_CYAN_LOW    (LED_GREEN_LOW     + LED_BLUE_LOW)
#define LED_CYAN_MEDIUM   (LED_GREEN_MEDIUM  + LED_BLUE_MEDIUM)
#define LED_CYAN_HIGH   (LED_GREEN_HIGH    + LED_BLUE_HIGH)

#define LED_WHITE_LOW   (LED_RED_LOW     + LED_GREEN_LOW     + LED_BLUE_LOW)
#define LED_WHITE_MEDIUM  (LED_RED_MEDIUM  + LED_GREEN_MEDIUM  + LED_BLUE_MEDIUM)
#define LED_WHITE_HIGH    (LED_RED_HIGH    + LED_GREEN_HIGH    + LED_BLUE_HIGH)

Adafruit_NeoMatrix matrix = Adafruit_NeoMatrix(5, 8, 24,
  NEO_MATRIX_TOP     + NEO_MATRIX_LEFT +
  NEO_MATRIX_COLUMNS + NEO_MATRIX_PROGRESSIVE,
  NEO_GRB            + NEO_KHZ800);

void setup() {
  matrix.begin();
  matrix.setBrightness(bright);

  logoAkana();
}

void loop() {
  matrix.clear();
  matrix.drawRoundRect(0, 0, 5, 8, 2, LED_PURPLE_MEDIUM);
  matrix.show();
  delay(1000);

  matrix.clear();
  matrix.fillRoundRect(0, 0, 5, 8, 2, LED_CYAN_MEDIUM);
  matrix.show();
  delay(1000);
  
  matrix.clear();
  matrix.drawTriangle(0, 3, 3, 0, 3, 6, LED_RED_MEDIUM);
  matrix.show();
  delay(1000);

  matrix.clear();
  matrix.fillTriangle(0, 3, 3, 0, 3, 6, LED_BLUE_MEDIUM);
  matrix.show();
  delay(1000);

  matrix.clear();
  matrix.drawLine(0, 0, 4, 4, LED_RED_MEDIUM);
  matrix.drawLine(0, 1, 4, 5, LED_BLUE_MEDIUM);
  matrix.drawLine(0, 2, 4, 6, LED_GREEN_MEDIUM);
  matrix.drawLine(0, 3, 4, 7, LED_WHITE_MEDIUM);
  matrix.show();
  delay(1000);
  
  matrix.clear();
  matrix.drawRect(0, 0, 5, 8, LED_CYAN_MEDIUM);
  matrix.fillRect(1, 1, 3, 6, LED_PURPLE_MEDIUM);
  matrix.show();
  delay(1000);
  
  matrix.clear();
  matrix.drawRect(0, 0, 5, 8, LED_BLUE_MEDIUM);
  matrix.drawLine(1, 1, 1, 6, LED_RED_MEDIUM);
  matrix.show();
  delay(1000);
  
  matrix.clear();
  matrix.drawCircle(2, 2, 2, LED_RED_MEDIUM);
  matrix.drawPixel(2, 2, LED_BLUE_MEDIUM);
  matrix.fillCircle(2, 6, 1, LED_BLUE_MEDIUM);
  matrix.show();
  delay(1000);
}