/*
  NeoScroll5 v1

  Scrolls Text with a Height of 5 Pixels Using the NeoMatrix Library and Custom Font.
  
  Board : METE HOCA Akana R1
  Dock  : RGB Matrix Dock Rev.1
  Core  : earlephilhower / arduino-pico (https://github.com/earlephilhower/arduino-pico)
  Required Libraries : U8G2 (https://github.com/olikraus/u8g2)
                       Adafruit NeoPixel (https://github.com/adafruit/Adafruit_NeoPixel)
                       Adafruit NeoMatrix (https://github.com/adafruit/Adafruit_NeoMatrix)
                       Adafruit GFX (https://github.com/adafruit/Adafruit-GFX-Library)
  Settings: Select METE HOCA Akana R1 as the board.

  Source : Adafruit / METE HOCA
  
  METE HOCA, 19 May 2024
  IG : https://www.instagram.com/metehoca/
  YT : https://www.youtube.com/MeteHoca
  WEB: https://www.metehoca.com/
*/

#include "AkanaLogo.h"

#include <Adafruit_GFX.h>
#include <Adafruit_NeoPixel.h>
#include <Adafruit_NeoMatrix.h>
#include <Fonts/TomThumb.h>

int bright = 32;
const char message[] = "METE HOCA AKANA R1";
uint16_t message_width;

Adafruit_NeoMatrix matrix(8, 5, 24,
  NEO_MATRIX_TOP  + NEO_MATRIX_LEFT +
  NEO_MATRIX_ROWS + NEO_MATRIX_PROGRESSIVE,
  NEO_GRB         + NEO_KHZ800);

const uint16_t colors[] = {
  matrix.Color(255, 0, 0), matrix.Color(0, 255, 0), matrix.Color(0, 0, 255) };

void setup() {
  matrix.begin();
  matrix.setBrightness(bright);
  matrix.setFont(&TomThumb);
  matrix.setTextWrap(false);
  matrix.setTextColor(colors[0]);
  int16_t  d1;
  uint16_t d2;
  matrix.getTextBounds(message, 0, 0, &d1, &d1, &message_width, &d2);
  logoAkana();
}

int x = matrix.width();
int y = matrix.height();
int pass = 0;

void loop() {
  matrix.fillScreen(0);
  matrix.setCursor(x, y);
  matrix.print(message);
  matrix.show();
  if(--x < -message_width) {
    x = matrix.width();
    if(++pass >= 3) pass = 0;
    matrix.setTextColor(colors[pass]);
  }
  delay(100);
}