/*
  Strobe2 v1

  Displays a Police Light Using NeoMatrix Library Commands.
  
  Board : METE HOCA Akana R1
  Dock  : RGB Matrix Dock Rev.1
  Core  : earlephilhower / arduino-pico (https://github.com/earlephilhower/arduino-pico)
  Required Libraries : U8G2 (https://github.com/olikraus/u8g2)
                       Adafruit NeoPixel (https://github.com/adafruit/Adafruit_NeoPixel)
                       Adafruit NeoMatrix (https://github.com/adafruit/Adafruit_NeoMatrix)
                       Adafruit GFX (https://github.com/adafruit/Adafruit-GFX-Library)
  Settings: Select METE HOCA Akana R1 as the board.

  Source : METE HOCA
  
  METE HOCA, 19 May 2024
  IG : https://www.instagram.com/metehoca/
  YT : https://www.youtube.com/MeteHoca
  WEB: https://www.metehoca.com/
*/

#include "AkanaLogo.h"
#include <Adafruit_GFX.h>
#include <Adafruit_NeoMatrix.h>
#include <Adafruit_NeoPixel.h>

int bright = 32;
int wait = 70;

#define LED_BLACK    0

#define LED_RED_LOW     (7 <<  11)
#define LED_RED_MEDIUM    (15 << 11)
#define LED_RED_HIGH    (31 << 11)

#define LED_GREEN_LOW     (15 << 5)  
#define LED_GREEN_MEDIUM  (31 << 5)  
#define LED_GREEN_HIGH    (63 << 5)  

#define LED_BLUE_LOW    7
#define LED_BLUE_MEDIUM   15
#define LED_BLUE_HIGH     31

#define LED_ORANGE_LOW    (LED_RED_LOW     + LED_GREEN_LOW)
#define LED_ORANGE_MEDIUM (LED_RED_MEDIUM  + LED_GREEN_MEDIUM)
#define LED_ORANGE_HIGH   (LED_RED_HIGH    + LED_GREEN_HIGH)

#define LED_PURPLE_LOW    (LED_RED_LOW     + LED_BLUE_LOW)
#define LED_PURPLE_MEDIUM (LED_RED_MEDIUM  + LED_BLUE_MEDIUM)
#define LED_PURPLE_HIGH   (LED_RED_HIGH    + LED_BLUE_HIGH)

#define LED_CYAN_LOW    (LED_GREEN_LOW     + LED_BLUE_LOW)
#define LED_CYAN_MEDIUM   (LED_GREEN_MEDIUM  + LED_BLUE_MEDIUM)
#define LED_CYAN_HIGH   (LED_GREEN_HIGH    + LED_BLUE_HIGH)

#define LED_WHITE_LOW   (LED_RED_LOW     + LED_GREEN_LOW     + LED_BLUE_LOW)
#define LED_WHITE_MEDIUM  (LED_RED_MEDIUM  + LED_GREEN_MEDIUM  + LED_BLUE_MEDIUM)
#define LED_WHITE_HIGH    (LED_RED_HIGH    + LED_GREEN_HIGH    + LED_BLUE_HIGH)

Adafruit_NeoMatrix matrix = Adafruit_NeoMatrix(5, 8, 24,
  NEO_MATRIX_TOP     + NEO_MATRIX_LEFT +
  NEO_MATRIX_COLUMNS + NEO_MATRIX_PROGRESSIVE,
  NEO_GRB            + NEO_KHZ800);

void setup() {
  matrix.begin();
  matrix.setBrightness(bright);

  logoAkana();
}

void loop() {
  matrix.fillRect(0, 4, 5, 4, LED_WHITE_MEDIUM);
  for (int x = 0; x < 4; x++) {
    matrix.fillRect(0, 0, 5, 4, LED_RED_HIGH);
    matrix.show();
    delay(wait);
    matrix.fillRect(0, 0, 5, 4, LED_WHITE_MEDIUM);
    matrix.show();
    delay(wait);
  }
  matrix.fillRect(0, 0, 5, 4, LED_WHITE_MEDIUM);
  for (int x = 0; x < 4; x++) {
    matrix.fillRect(0, 4, 5, 4, LED_BLUE_HIGH);
    matrix.show();
    delay(wait);
    matrix.fillRect(0, 4, 5, 4, LED_WHITE_MEDIUM);
    matrix.show();
    delay(wait);
  }
}