/*
  Cypher v1

  Creates Matrix Animation Using NeoMatrix Library.
  
  Board : METE HOCA Akana R1
  Dock  : RGB Matrix Dock Rev.1
  Core  : earlephilhower / arduino-pico (https://github.com/earlephilhower/arduino-pico)
  Required Libraries : U8G2 (https://github.com/olikraus/u8g2)
                       Adafruit NeoPixel (https://github.com/adafruit/Adafruit_NeoPixel)
                       Adafruit NeoMatrix (https://github.com/adafruit/Adafruit_NeoMatrix)
                       Adafruit GFX (https://github.com/adafruit/Adafruit-GFX-Library)
  Settings: Select METE HOCA Akana R1 as the board.

  Source : METE HOCA
  
  METE HOCA, 19 May 2024
  IG : https://www.instagram.com/metehoca/
  YT : https://www.youtube.com/MeteHoca
  WEB: https://www.metehoca.com/
*/

#include "AkanaLogo.h"
#include <Adafruit_NeoPixel.h>
#include <Adafruit_NeoMatrix.h>
#include <Adafruit_GFX.h>

int wait = 100;
int bright = 32;

Adafruit_NeoMatrix matrix = Adafruit_NeoMatrix(5, 8, 24, 
  NEO_MATRIX_TOP     + NEO_MATRIX_LEFT +
  NEO_MATRIX_COLUMNS + NEO_MATRIX_PROGRESSIVE,
  NEO_GRB            + NEO_KHZ800);

void setup() {
  matrix.begin();
  matrix.setBrightness(bright);
  matrix.show();

  logoAkana();
}

void loop() {
  static int positions[8];

  for (int i = 0; i < 8; i++) {
    if (random(10) > 7) positions[i] = 0;
  }

  while (true) {
    matrix.fillScreen(0);
    for (int col = 0; col < 8; col++) {
      int row = positions[col];
      if (row >= 0 && row < 5) {
        matrix.drawPixel(row, 7 - col, matrix.Color(0, 255, 0));
        if (row > 0) matrix.drawPixel(row - 1, 7 - col, matrix.Color(0, 128, 0));
      }
      positions[col]++;
      if (positions[col] >= 5 && random(10) > 7) positions[col] = 0;
    }
    matrix.show();
    delay(wait);
  }
}